caellion-python-commons: version-check.py File Reference

caellion-python-commons

Namespaces | Variables
version-check.py File Reference

Go to the source code of this file.

## Namespaces
| version-check

## Variables
string | version-check.version = "0.0.0"
string | version-check.commitid = "0000000"
string | version-check.branch = "unknown"
bool | version-check.is_initial = False
bool | version-check.invalid_set_version = False
string | version-check.set_version_term = "set-version"
string | version-check.bump_minor_term = "bump-minor"
string | version-check.bump_major_term = "bump-major"
int | version-check.major = 0
int | version-check.minor = 0
int | version-check.patch = 0
| version-check.describe = sys.argv[1]
| version-check.commits = sys.argv[3]
| version-check.dsplit = describe.split("-")
| version-check.splits = describe.split("-")
string | version-check.version_split = version.split(".")
int | version-check.bump_by = 1
int | version-check.major_new = major
int | version-check.minor_new = minor
int | version-check.patch_new = patch
| version-check.vsubs = commit.split("[" + set_version_term)
| version-check.file
| version-check.major_ = int(vsubs[0])
| version-check.minor_ = int(vsubs[1])
| version-check.patch_ = int(vsubs[2])
string | version-check.version_tag = str(major) + "." + str(minor) + "." + str(patch) + str("-") + branch
string | version-check.version_short = str(major) + "." + str(minor) + "." + str(patch)
string | version-check.final_version = str(major) + "." + str(minor) + "." + str(patch) + "-" + branch + "-" + commitid
| version-check.contents = fp.read()